local latestyear = 2018

cd "" //set as the path of this directory on your computer

* Read in and clean monitor data
import delimited "red_manual_particulas_susp.csv", varnames(9) rowrange(10) clear
drop unit 
gen day = substr(date, 1, strpos(date, "/")-1)
replace date = substr(date, strpos(date, "/")+1, length(date))
gen month = substr(date, 1, strpos(date, "/")-1)
replace date = substr(date, strpos(date, "/")+1, length(date))
rename date year
destring year month day, replace
rename cve_* *
order year month day station parameter value 

* Format as station-day panel dataset
replace parameter = "PM25" if parameter == "PM2.5"
reshape wide value, i(year month day station) j(parameter) string
rename value* *
rename (PST PM10 PM25) (tsp pm10 pm25)

* PM2.5/PM10, PM2.5/TSP, and PM10/TSP ratios for each station-day
gen pm25pm10ratio = pm25/pm10 
gen pm10tspratio = pm10/tsp
gen pm25tspratio = pm25/tsp 

* Aggregate to readings and ratios to station-month, then station-year level
sort year month station day
by year month station: gen numobs = _N 
collapse tsp pm10 pm25 *ratio numobs, by(year month station)
// in 1990, no more than 11 obs per month for any station. So can't impose minimum days per month criterion.
drop numobs 
bys year station: gen numobs = _N
collapse tsp pm10 pm25 *ratio numobs, by(year station)
// 7% of station-years have fewer than 8 months of data. Drop these.
keep if numobs>=8
drop numobs 
tempfile stationyeardata
save `"`stationyeardata'"'

* Aggregate ratios to station level and merge back in with readings 
collapse *ratio, by(station)
tempfile ratios
save `"`ratios'"'
use "`stationyeardata'", clear
merge m:1 station using "`ratios'", update replace
assert _merge>=3
drop _merge 
save `"`stationyeardata'"', replace

* Impute PM2.5 in 1990
sort station year 
keep if year == 1990
gen pm25_1990 = pm10*pm25pm10ratio
replace pm25_1990 = tsp*pm25tspratio if missing(pm25_1990)
replace pm25_1990 = tsp*pm10tspratio*pm25pm10ratio if missing(pm25_1990)
drop if missing(pm25_1990)
tempfile imputed1990
save `"`imputed1990'"'

* Confirm the stations for which we have imputed 1990 PM2.5
use "`stationyeardata'", clear
merge m:1 station using "`imputed1990'", keep(3) nogen
assert inlist(station, "MER", "PED", "TLA", "UIZ", "XAL")
distinct station 
assert `r(ndistinct)' == 5
drop *ratio 
save `"`stationyeardata'"', replace

* Merge in AQLI satellite-derived data for the municipalities that these stations are in 
use "satellitePM25_CDMX_edomex", clear
keep if country == "Mexico" & (name_1 == "Distrito Federal" & inlist(name_2, "Venustiano Carranza", "Alvaro Obregón", "Iztapalapa")) | ///
	(name_1 == "México" & inlist(name_2, "Ecatepec de Morelos", "Tlalnepantla"))
keep name_1 name_2 population pm*
reshape long pm, i(name_1 name_2 population) j(year)
rename pm pm25_satellite
gen station = "MER" if name_2 == "Venustiano Carranza"
replace station = "PED" if name_2 == "Alvaro Obregón"
replace station = "UIZ" if name_2 == "Iztapalapa"
replace station = "TLA" if name_2 == "Tlalnepantla"
replace station = "XAL" if name_2 == "Ecatepec de Morelos"
tempfile aqli
save `"`aqli'"'

use "`stationyeardata'", clear
merge 1:1 station year using "`aqli'", nogen

* Calculate average ratio between satellite-measured and monitor-recorded PM2.5 at each station 
gen satmonratio = pm25_satellite/pm25
bys station: egen satmonratioavg = mean(satmonratio)

* Calculate calibrated 1990 PM2.5
gen pm25_1990_aqli = pm25_1990*satmonratioavg

* Keep only necessary info
drop if year>`latestyear'
sort station year 
by station: gen pm25_`latestyear'_aqli = pm25_satellite[_N]
rename pm25 pm25_monitor
collapse pm25* population, by(station)
drop pm25_monitor pm25_satellite

* Calculate percent change in PM since 1990 and life expectancy gained
gen pctchg1990`latestyear' = (pm25_`latestyear'_aqli - pm25_1990_aqli)/pm25_1990_aqli
gen lys1990`latestyear' = (pm25_1990_aqli-pm25_`latestyear'_aqli)*0.098

* Get average across Mexico City 
summ pctchg1990`latestyear' lys1990`latestyear'
